@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 """
-This namespace contains rsgislib Python bindings 
+This namespace contains rsgislib Python bindings
 
-Please be aware that the following variables have been 
+Please be aware that the following variables have been
 defined to match enums within RSGISLib.
 
 Data Types for images:
@@ -163,6 +163,12 @@ Options for variable type
     * VAR_TYPE_CONTINUOUS = 1
     * VAR_TYPE_CATEGORICAL = 2
 
+
+Options for rounding numbers:
+    * ROUND_NEAREST = 1
+    * ROUND_UP = 2
+    * ROUND_DOWN = 3
+
 """
 from __future__ import print_function
 
@@ -301,6 +307,10 @@ VAR_TYPE_UNDEFINED = 0
 VAR_TYPE_CONTINUOUS = 1
 VAR_TYPE_CATEGORICAL = 2
 
+ROUND_NEAREST = 1
+ROUND_UP = 2
+ROUND_DOWN = 3
+
 
 def get_install_base_path() -> pathlib.PurePath:
     """
