@@ -322,9 +322,9 @@ def get_class_training_data(
 
     rasterise_ref_img = ref_img
     if ref_img is None:
-        rasterise_ref_img = os.path.join(tmp_lcl_dir, "ref_img_vmsk.kea")
+        rasterise_ref_img = os.path.join(tmp_lcl_dir, "ref_img_vmsk.tif")
         rsgislib.imageutils.create_valid_mask(
-            img_band_info, rasterise_ref_img, "KEA", tmp_lcl_dir
+            img_band_info, rasterise_ref_img, "GTIFF", tmp_lcl_dir
         )
 
     class_info = dict()
@@ -332,29 +332,30 @@ def get_class_training_data(
         cls_basename = rsgislib.tools.filetools.get_file_basename(
             class_sample_info.file_h5
         )
-        out_vec_img = os.path.join(tmp_lcl_dir, "{}_img.kea".format(cls_basename))
+        out_vec_img = os.path.join(tmp_lcl_dir, "{}_img.tif".format(cls_basename))
         rsgislib.vectorutils.createrasters.rasterise_vec_lyr(
             class_sample_info.vec_file,
             class_sample_info.vec_lyr,
             rasterise_ref_img,
             out_vec_img,
-            gdalformat="KEA",
+            gdalformat="GTIFF",
             burn_val=class_sample_info.id,
             datatype=rsgislib.TYPE_16UINT,
             att_column=None,
             use_vec_extent=False,
             thematic=True,
             no_data_val=0,
+            calc_stats = False,
         )
 
         if sub_sample is not None:
             out_vec_img_subsample = os.path.join(
-                tmp_lcl_dir, "{}_img_subsample.kea".format(cls_basename)
+                tmp_lcl_dir, "{}_img_subsample.tif".format(cls_basename)
             )
             rsgislib.imageutils.perform_random_pxl_sample_in_mask(
                 out_vec_img,
                 out_vec_img_subsample,
-                "KEA",
+                "GTIFF",
                 mask_vals=[class_sample_info.id],
                 n_samples=sub_sample,
             )
@@ -1593,3 +1594,27 @@ def convert_mutli_cls_smpls_to_pandas_df(
 
     data_cls_vals_df = pandas.concat((cls_id_df, data_vals_df), axis=1)
     return data_cls_vals_df
+
+
+def apply_class_clrs(input_cls_img: str,
+                     cls_info_dict: Dict[str, ClassInfoObj]):
+    """
+    A function which uses the cls_train_info dict to define the colours for the
+    input image colour table.
+
+    :param input_cls_img: Input classification image (needs to be 8 bit unsigned int)
+    :param cls_info_dict: dict (where the key is the class name) of
+                           rsgislib.classification.ClassInfoObj objects which will be
+                           used to train the classifier provide pixel value id and
+                           RGB class values.
+
+    """
+    import rsgislib.imageutils
+
+    clr_lut = dict()
+    for class_key in cls_info_dict:
+        clr_lut[cls_info_dict[class_key].out_id] = [cls_info_dict[class_key].red,
+                                                     cls_info_dict[class_key].green,
+                                                     cls_info_dict[class_key].blue]
+
+    rsgislib.imageutils.define_colour_table(input_cls_img, clr_lut)
