@@ -673,6 +673,37 @@ def get_dir_list(dir_path: str, inc_hidden: bool = False) -> list:
                 out_dir_lst.append(c_path)
     return out_dir_lst
 
+def get_dir_list_srch(dir_path: str, name_inc:str, inc_hidden: bool = False) -> list:
+    """
+    Function which get the list of directories within the specified path where
+    the name contains a particular string.
+
+    :param dir_path: file path to search within
+    :param name_inc: string within the directory name
+    :param inc_hidden: boolean specifying whether hidden files should be
+                       included (default=False)
+    :return: list of directory paths
+
+    Example:
+
+    .. code:: python
+
+        import rsgislib.tools.filetools
+        files = rsgislib.tools.filetools.get_dir_list("in/dir")
+
+    """
+    out_dir_lst = list()
+    dir_listing = os.listdir(dir_path)
+    for item in dir_listing:
+        c_path = os.path.join(dir_path, item)
+        if os.path.isdir(c_path):
+            if name_inc in item:
+                if not inc_hidden:
+                    if not file_is_hidden(c_path):
+                        out_dir_lst.append(c_path)
+                else:
+                    out_dir_lst.append(c_path)
+    return out_dir_lst
 
 def convert_file_size_units(in_size: int, in_unit: str, out_unit: str) -> float:
     """
@@ -756,6 +787,24 @@ def get_file_size(file_path: str, unit: str = "bytes") -> float:
     return out_file_size
 
 
+def get_file_mod_time(file_path: str) -> datetime.datetime:
+    """
+    A function which finding the modification time of a file and returns it as
+    a datetime object.
+
+    :param file_path: The file path as a string
+    :return: The modification time as a datetime object
+
+    """
+    if not os.path.exists(file_path):
+        raise rsgislib.RSGISPyException(f"File path does not exist: {file_path}")
+
+    mod_time_stamp = os.path.getmtime(file_path)
+    mod_datetime_obj = datetime.datetime.fromtimestamp(mod_time_stamp)
+
+    return mod_datetime_obj
+
+
 def get_file_lock(
     input_file: str,
     sleep_period: int = 1,
@@ -870,16 +919,16 @@ def sort_imgs_to_dirs_utm(input_imgs_dir: str, file_search_str: str, out_base_di
 
     in_files = glob.glob(os.path.join(input_imgs_dir, file_search_str))
     for img_file in in_files:
-        utm_zone = rsgislib.imageutils.getUTMZone(img_file)
+        utm_zone = rsgislib.imageutils.get_utm_zone(img_file)
         if utm_zone is not None:
             out_dir = os.path.join(out_base_dir, "utm" + utm_zone)
             if not os.path.exists(out_dir):
                 os.makedirs(out_dir)
-            img_file_list = rsgislib.imageutils.getImageFiles(img_file)
+            img_file_list = rsgislib.imageutils.get_img_files(img_file)
             for tmp_file in img_file_list:
-                print("Moving: " + tmp_file)
-                outFile = os.path.join(out_dir, os.path.basename(tmp_file))
-                shutil.move(tmp_file, outFile)
+                print(f"Moving: {tmp_file}")
+                out_file = os.path.join(out_dir, os.path.basename(tmp_file))
+                shutil.move(tmp_file, out_file)
 
 
 def natural_sort_file_names(in_file_lst: List[str]) -> List[str]:
