@@ -14,6 +14,7 @@ from matplotlib.patches import Patch
 from osgeo import gdal
 
 import rsgislib
+import rsgislib.classification
 from rsgislib import imagecalc, zonalstats
 
 have_mpl_scatter_density = True
@@ -1041,9 +1042,10 @@ def linear_stretch_np_arr(
     no_data_val: float = None,
     out_off: float = 0,
     out_gain: float = 1,
-    out_int_type=False,
+    out_int_type: bool = False,
     min_out_val: float = 0,
     max_out_val: float = 1,
+    no_data_clr: Tuple[float, float, float] = None,
 ) -> numpy.array:
     """
     A function which performs a linear stretch using the min-max values on a per
@@ -1086,9 +1088,14 @@ def linear_stretch_np_arr(
 
     """
     arr_shp = arr_data.shape
+    if len(arr_shp) == 2:
+        n_bands = 1
+    else:
+        n_bands = arr_shp[2]
 
     if no_data_val is not None:
-        arr_data_out = arr_data.astype(float)
+        arr_data_out = arr_data.copy()
+        arr_data_out = arr_data_out.astype(float)
         arr_data_out[arr_data == no_data_val] = numpy.nan
     else:
         arr_data_out = arr_data.copy()
@@ -1101,7 +1108,6 @@ def linear_stretch_np_arr(
 
         arr_data_out = (((arr_data_out - min_val) / range_val) * out_gain) + out_off
     else:
-        n_bands = arr_shp[2]
         for n in range(n_bands):
             min_val = numpy.nanmin(arr_data_out[..., n])
             max_val = numpy.nanmax(arr_data_out[..., n])
@@ -1119,6 +1125,11 @@ def linear_stretch_np_arr(
         max_out_val=max_out_val,
     )
 
+    if (no_data_val is not None) and (no_data_clr is not None):
+        for n in range(n_bands):
+            no_data_msk = arr_data[..., n] == no_data_val
+            arr_data_out[no_data_msk, n] = no_data_clr[n]
+
     if out_int_type:
         arr_data_out = arr_data_out.astype(int)
 
@@ -1132,9 +1143,10 @@ def cumulative_stretch_np_arr(
     upper: int = 98,
     out_off: float = 0,
     out_gain: float = 1,
-    out_int_type=False,
+    out_int_type: bool = False,
     min_out_val: float = 0,
     max_out_val: float = 1,
+    no_data_clr: Tuple[float, float, float] = None,
 ) -> numpy.array:
     """
     A function which performs a cumulative stretch using an upper and lower
@@ -1179,9 +1191,14 @@ def cumulative_stretch_np_arr(
 
     """
     arr_shp = arr_data.shape
+    if len(arr_shp) == 2:
+        n_bands = 1
+    else:
+        n_bands = arr_shp[2]
 
     if no_data_val is not None:
-        arr_data_out = arr_data.astype(float)
+        arr_data_out = arr_data.copy()
+        arr_data_out = arr_data_out.astype(float)
         arr_data_out[arr_data == no_data_val] = numpy.nan
     else:
         arr_data_out = arr_data.copy()
@@ -1193,7 +1210,6 @@ def cumulative_stretch_np_arr(
 
         arr_data_out = (((arr_data_out - min_val) / range_val) * out_gain) + out_off
     else:
-        n_bands = arr_shp[2]
         for n in range(n_bands):
             min_val, max_val = numpy.nanpercentile(arr_data_out[..., n], [lower, upper])
             range_val = max_val - min_val
@@ -1210,6 +1226,11 @@ def cumulative_stretch_np_arr(
         max_out_val=max_out_val,
     )
 
+    if (no_data_val is not None) and (no_data_clr is not None):
+        for n in range(n_bands):
+            no_data_msk = arr_data[..., n] == no_data_val
+            arr_data_out[no_data_msk, n] = no_data_clr[n]
+
     if out_int_type:
         arr_data_out = arr_data_out.astype(int)
 
@@ -1222,9 +1243,10 @@ def stdev_stretch_np_arr(
     n_stdevs: float = 2.0,
     out_off: float = 0,
     out_gain: float = 1,
-    out_int_type=False,
+    out_int_type: bool = False,
     min_out_val: float = 0,
     max_out_val: float = 1,
+    no_data_clr: Tuple[float, float, float] = None,
 ) -> numpy.array:
     """
     A function which performs a standard deviation stretch using an upper and lower
@@ -1269,9 +1291,14 @@ def stdev_stretch_np_arr(
 
     """
     arr_shp = arr_data.shape
+    if len(arr_shp) == 2:
+        n_bands = 1
+    else:
+        n_bands = arr_shp[2]
 
     if no_data_val is not None:
-        arr_data_out = arr_data.astype(float)
+        arr_data_out = arr_data.copy()
+        arr_data_out = arr_data_out.astype(float)
         arr_data_out[arr_data == no_data_val] = numpy.nan
     else:
         arr_data_out = arr_data.copy()
@@ -1323,6 +1350,11 @@ def stdev_stretch_np_arr(
         max_out_val=max_out_val,
     )
 
+    if (no_data_val is not None) and (no_data_clr is not None):
+        for n in range(n_bands):
+            no_data_msk = arr_data[..., n] == no_data_val
+            arr_data_out[no_data_msk, n] = no_data_clr[n]
+
     if out_int_type:
         arr_data_out = arr_data_out.astype(int)
 
@@ -1335,9 +1367,10 @@ def manual_stretch_np_arr(
     no_data_val: float = None,
     out_off: float = 0,
     out_gain: float = 1,
-    out_int_type=False,
+    out_int_type: bool = False,
     min_out_val: float = 0,
     max_out_val: float = 1,
+    no_data_clr: Tuple[float, float, float] = None,
 ) -> numpy.array:
     """
     A function which performs a linear stretch using the min-max values provided
@@ -1392,9 +1425,14 @@ def manual_stretch_np_arr(
 
     """
     arr_shp = arr_data.shape
+    if len(arr_shp) == 2:
+        n_bands = 1
+    else:
+        n_bands = arr_shp[2]
 
     if no_data_val is not None:
-        arr_data_out = arr_data.astype(float)
+        arr_data_out = arr_data.copy()
+        arr_data_out = arr_data_out.astype(float)
         arr_data_out[arr_data == no_data_val] = numpy.nan
     else:
         arr_data_out = arr_data.copy()
@@ -1454,6 +1492,11 @@ def manual_stretch_np_arr(
         max_out_val=max_out_val,
     )
 
+    if (no_data_val is not None) and (no_data_clr is not None):
+        for n in range(n_bands):
+            no_data_msk = arr_data[..., n] == no_data_val
+            arr_data_out[no_data_msk, n] = no_data_clr[n]
+
     if out_int_type:
         arr_data_out = arr_data_out.astype(int)
 
@@ -1461,7 +1504,7 @@ def manual_stretch_np_arr(
 
 
 def create_legend_img(
-    legend_info: Dict,
+    legend_info: Dict[str, Tuple[int, int, int, int]],
     n_cols: int = 1,
     box_size: Tuple[int] = (10, 20),
     title_str: str = None,
@@ -1580,7 +1623,7 @@ def create_legend_img(
 
 
 def create_legend_img_file(
-    legend_info: Dict,
+    legend_info: Dict[str, Tuple[int, int, int, int]],
     out_img_file: str,
     n_cols: int = 1,
     box_size: Tuple[int] = (10, 20),
@@ -1648,7 +1691,7 @@ def create_legend_img_file(
 
 def create_legend_img_mpl_ax(
     ax: plt.axis,
-    legend_info: Dict,
+    legend_info: Dict[str, Tuple[int, int, int, int]],
     n_cols: int = 1,
     box_size: Tuple[int] = (10, 20),
     title_str: str = None,
@@ -1735,7 +1778,7 @@ def create_legend_info_dict(
     blue_col: str = "Blue",
     alpha_col: str = "Alpha",
     histogram_col: str = "Histogram",
-) -> Dict[str, Tuple[int]]:
+) -> Dict[str, Tuple[int, int, int, int]]:
     """
     A function which creates the legend_info dict for the create_legend_img function
     from an input image file with RAT. It assumes that the RAT contains a column with
@@ -1791,6 +1834,43 @@ def create_legend_info_dict(
     return out_cls_info
 
 
+def create_legend_info_dict_from_cls_info(
+    cls_info_dict: Dict[str, rsgislib.classification.ClassInfoObj],
+    use_title_case=False,
+    underscore_to_space=False,
+) -> Dict[str, Tuple[int, int, int, int]]:
+    """
+    A function which creates the legend_info dict for the create_legend_img function
+    from an input image file with RAT. It assumes that the RAT contains a column with
+    the class names and columns with the class colours.
+
+    :param cls_info_dict: a dict where the key is string with class name
+                          of ClassInfoObj objects defining the training data.
+                          This is used to define the class names and colours
+                          if class_clr_names is True.
+    :param use_title_case: Change the class name to title case (Default: False)
+    :param underscore_to_space: Convert underscores in the class name to spaces
+                                (Default: False)
+    :return: dictionary with the classification name as the key and the value a tuple
+             of [Red, Green, Blue, Alpha] values.
+
+    """
+
+    out_cls_info = dict()
+    for cls_name in cls_info_dict:
+        cls_name_str = str(cls_name)
+        if (cls_name_str != ""):
+            if underscore_to_space:
+                cls_name_str = cls_name_str.replace("_", " ")
+
+            if use_title_case:
+                cls_name_str = cls_name_str.title()
+
+            out_cls_info[cls_name_str] = (int(cls_info_dict[cls_name].red), int(cls_info_dict[cls_name].green), int(cls_info_dict[cls_name].blue), 255)
+
+    return out_cls_info
+
+
 def gen_colour_lst(cmap_name: str, n_clrs: int, reverse: bool = False) -> List[str]:
     """
     A function which gets a list of colours as hex strings from a matplotlib colour
