@@ -265,20 +265,20 @@ def extract_image_footprint(
 
     in_img_base = os.path.splitext(os.path.basename(input_img))[0]
 
-    valid_out_img = os.path.join(tmp_dir, in_img_base + "_" + uid_str + "_validimg.kea")
+    valid_out_img = os.path.join(tmp_dir, f"{in_img_base}_{uid_str}_validimg.tif")
     if no_data_val is None:
         no_data_val = rsgislib.imageutils.get_img_no_data_value(input_img)
 
     if no_data_val is None:
         raise rsgislib.RSGISPyException("A no data value has not been specified.")
     rsgislib.imageutils.gen_valid_mask(
-        input_img, valid_out_img, gdalformat="KEA", no_data_val=no_data_val
+        input_img, valid_out_img, gdalformat="GTIFF", no_data_val=no_data_val
     )
 
     out_vec_tmp_file = out_vec_file
     if reproj_to is not None:
         out_vec_tmp_file = os.path.join(
-            tmp_dir, in_img_base + "_" + uid_str + "_initVecOut.gpkg"
+            tmp_dir, f"{in_img_base}_{uid_str}_initVecOut.gpkg"
         )
 
     polygonise_raster_to_vec_lyr(
@@ -332,7 +332,7 @@ def extract_image_footprint(
         shutil.rmtree(tmp_dir)
     else:
         if reproj_to is not None:
-            driver = ogr.GetDriverByName("ESRI Shapefile")
+            driver = ogr.GetDriverByName(out_format)
             driver.DeleteDataSource(out_vec_tmp_file)
 
 
@@ -1258,8 +1258,9 @@ def create_hex_grid_bbox(
 
     """
     import geopandas
-    from h3 import h3
+    import h3
     from shapely.geometry import Polygon
+    import shapely
 
     import rsgislib.tools.geometrytools
 
@@ -1272,9 +1273,9 @@ def create_hex_grid_bbox(
 
     bbox_poly = rsgislib.tools.geometrytools.get_bbox_geojson_poly(bbox_wgs84)
 
-    hexs = h3.polyfill(bbox_poly, hex_scale, geo_json_conformant=True)
+    hexs = h3.h3shape_to_cells(h3.geo_to_h3shape(bbox_poly), hex_scale)
 
-    polygonise = lambda hex_id: Polygon(h3.h3_to_geo_boundary(hex_id, geo_json=True))
+    polygonise = lambda hex_id: Polygon(h3.cell_to_boundary(hex_id))
 
     all_polys = geopandas.GeoSeries(
         list(map(polygonise, hexs)), index=hexs, crs="EPSG:4326"
@@ -1285,6 +1286,9 @@ def create_hex_grid_bbox(
         h3_all = geopandas.GeoDataFrame(
             {"geometry": all_polys, "hex_id": all_polys.index}, crs=all_polys.crs
         )
+        h3_all["geometry"] = h3_all.geometry.map(
+            lambda polygon: shapely.ops.transform(lambda x, y: (y, x), polygon)
+        )
 
         if bbox_epsg != 4326:
             h3_all = h3_all.to_crs(f"EPSG:{bbox_epsg}")
@@ -1311,7 +1315,8 @@ def create_hex_grid_poly(poly_series, hex_scale: int):
 
     """
     import geopandas
-    from h3 import h3
+    import shapely
+    import h3
     from shapely.geometry import MultiPolygon, Polygon
 
     geom = poly_series.geometry
@@ -1328,9 +1333,9 @@ def create_hex_grid_poly(poly_series, hex_scale: int):
                 new_multi_p.append(new_p)
             geom = MultiPolygon(new_multi_p)
 
-    hexs = h3.polyfill(geom.__geo_interface__, hex_scale, geo_json_conformant=True)
+    hexs = h3.h3shape_to_cells(h3.geo_to_h3shape(geom.__geo_interface__), hex_scale)
 
-    polygonise = lambda hex_id: Polygon(h3.h3_to_geo_boundary(hex_id, geo_json=True))
+    polygonise = lambda hex_id: Polygon(h3.cell_to_boundary(hex_id))
 
     all_polys = geopandas.GeoSeries(
         list(map(polygonise, hexs)), index=hexs, crs="EPSG:4326"
@@ -1340,6 +1345,9 @@ def create_hex_grid_poly(poly_series, hex_scale: int):
         h3_all = geopandas.GeoDataFrame(
             {"geometry": all_polys, "hex_id": all_polys.index}, crs=all_polys.crs
         )
+        h3_all["geometry"] = h3_all.geometry.map(
+            lambda polygon: shapely.ops.transform(lambda x, y: (y, x), polygon)
+        )
     else:
         h3_all = None
     return h3_all
