@@ -280,12 +280,12 @@ def test_flip_ref_chip_hdf5_file(tmp_path):
 
     assert os.path.exists(out_h5_file)
 
-
+@pytest.mark.skipif(H5PY_NOT_AVAIL, reason="h5py dependency not available")
 def test_get_class_training_data(tmp_path):
     import rsgislib.imageutils
     import rsgislib.classification
 
-    s2_img = os.path.join(DATA_DIR, "sen2_20210527_aber.kea")
+    s2_img = os.path.join(DATA_DIR, "sen2_20210527_aber.tif")
     cls_vec_smpls = os.path.join(CLASSIFICATION_DATA_DIR, "cls_poly_smpls.gpkg")
 
     img_band_info = []
