@@ -29,7 +29,7 @@ namespace rsgis{ namespace classifier{
 	{
 		
 	}
-
+    /*
 	ClassData* RSGISClassificationUtils::convertROIs2ClassData(rsgis::utils::enviroi *enviroi, int id)
 	{
         rsgis::math::RSGISMatrices matrixUtils;
@@ -40,7 +40,7 @@ namespace rsgis{ namespace classifier{
 		return classData;
 	}
 
-	ClassData** RSGISClassificationUtils::parseClassificationInputFile(std::string inputFile, int *numClasses) throw(RSGISClassificationException, rsgis::RSGISInputStreamException, rsgis::math::RSGISMatricesException)
+	ClassData** RSGISClassificationUtils::parseClassificationInputFile(std::string inputFile, int *numClasses)
 	{
         rsgis::math::RSGISMathsUtils mathsUtils;
         rsgis::math::RSGISMatrices matrixUtils;
@@ -130,24 +130,26 @@ namespace rsgis{ namespace classifier{
 			std::string outMessage =  std::string("DOMException : ") + std::string(message);
 			throw RSGISClassificationException(outMessage.c_str());
 		}
-		catch(RSGISInputStreamException e)
+		catch(RSGISInputStreamException &e)
 		{
 			throw e;
 		}
-		catch(RSGISClassificationException e)
+		catch(RSGISClassificationException &e)
 		{
 			throw e;
 		}
-		catch(rsgis::math::RSGISMatricesException e)
+		catch(rsgis::math::RSGISMatricesException &e)
 		{
 			throw e;
 		}
 		
 		return classData;
 	}
+     */
 	
-	void RSGISClassificationUtils::convertShapeFile2SpecLib(std::string vector, std::string outputFile, std::string classAttribute, std::vector<std::string> *attributes, bool group) throw(RSGISClassificationException)
+	void RSGISClassificationUtils::convertShapeFile2SpecLib(std::string vector, std::string outputFile, std::string classAttribute, std::vector<std::string> *attributes, bool group)
 	{
+	    /*
 		OGRRegisterAll();
 		
         rsgis::vec::RSGISVectorUtils vecUtils;
@@ -286,6 +288,7 @@ namespace rsgis{ namespace classifier{
 		{
 			throw RSGISClassificationException(e.what());
 		}
+	     */
 	}
 
 	RSGISClassificationUtils::~RSGISClassificationUtils()
@@ -299,7 +302,7 @@ namespace rsgis{ namespace classifier{
         
     }
     
-    void RSGISEliminateSingleClassPixels::eliminate(GDALDataset *inImageData, GDALDataset *tmpData, std::string outputImage, float noDataVal, bool noDataValProvided, std::string format, rsgis::img::RSGISRasterConnectivity filterConnectivity)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISEliminateSingleClassPixels::eliminate(GDALDataset *inImageData, GDALDataset *tmpData, std::string outputImage, float noDataVal, bool noDataValProvided, std::string format, rsgis::img::RSGISRasterConnectivity filterConnectivity)
     {
         try
         {
@@ -377,7 +380,7 @@ namespace rsgis{ namespace classifier{
         }
     }
     
-    unsigned long RSGISEliminateSingleClassPixels::findSinglePixelsConnect4(GDALDataset *inImageData, GDALDataset *tmpData, float noDataVal, bool noDataValProvided) throw(rsgis::img::RSGISImageCalcException)
+    unsigned long RSGISEliminateSingleClassPixels::findSinglePixelsConnect4(GDALDataset *inImageData, GDALDataset *tmpData, float noDataVal, bool noDataValProvided) 
     {
         unsigned long countSingles = 0;
         try
@@ -395,16 +398,10 @@ namespace rsgis{ namespace classifier{
             unsigned int *outData = new unsigned int[width];
             bool notSingle = false;
             
-            int feedback = height/10;
-            int feedbackCounter = 0;
-            std::cout << "Started" << std::flush;
+            rsgis_tqdm pbar;
             for(unsigned int i = 0; i < height; ++i)
             {
-                if((i % feedback) == 0)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, height);
                 if(i == 0)
                 {
                     clumpBand->RasterIO(GF_Read, 0, i, width, 1, inData[1], width, 1, GDT_UInt32, 0, 0);
@@ -634,7 +631,7 @@ namespace rsgis{ namespace classifier{
                 
                 tmpBand->RasterIO(GF_Write, 0, i, width, 1, outData, width, 1, GDT_UInt32, 0, 0);
             }
-            std::cout << ". Complete\n";
+            pbar.finish();
             
             delete[] inData[0];
             delete[] inData[1];
@@ -650,7 +647,7 @@ namespace rsgis{ namespace classifier{
         return countSingles;
     }
     
-    bool RSGISEliminateSingleClassPixels::eliminateSinglePixelsConnect4(GDALDataset *inImageData, GDALDataset *tmpData, GDALDataset *outDataset, float noDataVal, bool noDataValProvided) throw(rsgis::img::RSGISImageCalcException)
+    bool RSGISEliminateSingleClassPixels::eliminateSinglePixelsConnect4(GDALDataset *inImageData, GDALDataset *tmpData, GDALDataset *outDataset, float noDataVal, bool noDataValProvided) 
     {
         bool hasChangeOccured = false;
         try
@@ -676,16 +673,10 @@ namespace rsgis{ namespace classifier{
             
             unsigned int *outData = new unsigned int[width];
             
-            int feedback = height/10;
-            int feedbackCounter = 0;
-            std::cout << "Started" << std::flush;
+            rsgis_tqdm pbar;
             for(unsigned int i = 0; i < height; ++i)
             {
-                if((i % feedback) == 0)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, height);
                 if(i == 0)
                 {
                     clumpBand->RasterIO(GF_Read, 0, i, width, 1, inData[1], width, 1, GDT_UInt32, 0, 0);
@@ -1013,7 +1004,7 @@ namespace rsgis{ namespace classifier{
                 
                 outBand->RasterIO(GF_Write, 0, i, width, 1, outData, width, 1, GDT_UInt32, 0, 0);
             }
-            std::cout << ". Complete\n";
+            pbar.finish();
             
             delete sortedList;
             delete[] inData[0];
@@ -1033,7 +1024,7 @@ namespace rsgis{ namespace classifier{
         return hasChangeOccured;
     }
     
-    unsigned long RSGISEliminateSingleClassPixels::findSinglePixelsConnect8(GDALDataset *inImageData, GDALDataset *tmpData, float noDataVal, bool noDataValProvided) throw(rsgis::img::RSGISImageCalcException)
+    unsigned long RSGISEliminateSingleClassPixels::findSinglePixelsConnect8(GDALDataset *inImageData, GDALDataset *tmpData, float noDataVal, bool noDataValProvided) 
     {
         unsigned long countSingles = 0;
         try
@@ -1051,16 +1042,10 @@ namespace rsgis{ namespace classifier{
             unsigned int *outData = new unsigned int[width];
             bool notSingle = false;
             
-            int feedback = height/10;
-            int feedbackCounter = 0;
-            std::cout << "Started" << std::flush;
+            rsgis_tqdm pbar;
             for(unsigned int i = 0; i < height; ++i)
             {
-                if((i % feedback) == 0)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, height);
                 if(i == 0)
                 {
                     clumpBand->RasterIO(GF_Read, 0, i, width, 1, inData[1], width, 1, GDT_UInt32, 0, 0);
@@ -1370,7 +1355,7 @@ namespace rsgis{ namespace classifier{
                 
                 tmpBand->RasterIO(GF_Write, 0, i, width, 1, outData, width, 1, GDT_UInt32, 0, 0);
             }
-            std::cout << ". Complete\n";
+            pbar.finish();
             
             delete[] inData[0];
             delete[] inData[1];
@@ -1386,7 +1371,7 @@ namespace rsgis{ namespace classifier{
         return countSingles;
     }
     
-    bool RSGISEliminateSingleClassPixels::eliminateSinglePixelsConnect8(GDALDataset *inImageData, GDALDataset *tmpData, GDALDataset *outDataset, float noDataVal, bool noDataValProvided) throw(rsgis::img::RSGISImageCalcException)
+    bool RSGISEliminateSingleClassPixels::eliminateSinglePixelsConnect8(GDALDataset *inImageData, GDALDataset *tmpData, GDALDataset *outDataset, float noDataVal, bool noDataValProvided) 
     {
         bool hasChangeOccured = false;
         try
@@ -1412,16 +1397,10 @@ namespace rsgis{ namespace classifier{
             
             unsigned int *outData = new unsigned int[width];
             
-            int feedback = height/10;
-            int feedbackCounter = 0;
-            std::cout << "Started" << std::flush;
+            rsgis_tqdm pbar;
             for(unsigned int i = 0; i < height; ++i)
             {
-                if((i % feedback) == 0)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, height);
                 if(i == 0)
                 {
                     clumpBand->RasterIO(GF_Read, 0, i, width, 1, inData[1], width, 1, GDT_UInt32, 0, 0);
@@ -1829,7 +1808,7 @@ namespace rsgis{ namespace classifier{
                 
                 outBand->RasterIO(GF_Write, 0, i, width, 1, outData, width, 1, GDT_UInt32, 0, 0);
             }
-            std::cout << ". Complete\n";
+            pbar.finish();
             
             delete sortedList;
             delete[] inData[0];
