@@ -30,7 +30,7 @@ namespace rsgis{namespace classifier{
         
     }
     
-    void RSGISGenAccuracyPoints::generateRandomPoints(GDALDataset *inputImage, GDALDataset *inputDEM, bool demProvided, std::string outputFile, std::string classColName, unsigned int numPts, unsigned int seed) throw(rsgis::RSGISImageException)
+    void RSGISGenAccuracyPoints::generateRandomPoints(GDALDataset *inputImage, GDALDataset *inputDEM, bool demProvided, std::string outputFile, std::string classColName, unsigned int numPts, unsigned int seed)
     {
         try
         {
@@ -222,7 +222,7 @@ namespace rsgis{namespace classifier{
     }
     
     
-    void RSGISGenAccuracyPoints::generateStratifiedRandomPoints(GDALDataset *inputImage, GDALDataset *inputDEM, bool demProvided, std::string outputFile, std::string classColName, unsigned int numPts, unsigned int seed) throw(rsgis::RSGISImageException)
+    void RSGISGenAccuracyPoints::generateStratifiedRandomPoints(GDALDataset *inputImage, GDALDataset *inputDEM, bool demProvided, std::string outputFile, std::string classColName, unsigned int numPts, unsigned int seed)
     {
         try
         {
@@ -467,7 +467,7 @@ namespace rsgis{namespace classifier{
     }
     
     
-    void RSGISGenAccuracyPoints::generateRandomPointsVecOut(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int seed) throw(rsgis::RSGISImageException)
+    void RSGISGenAccuracyPoints::generateRandomPointsVecOut(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int seed)
     {
         try
         {
@@ -576,10 +576,18 @@ namespace rsgis{namespace classifier{
                 std::string message = std::string("Creating shapefile field \'") + vecClassRefCol + std::string("\' has failed");
                 throw rsgis::RSGISException(message);
             }
+
+            OGRFieldDefn processedField("Processed", OFTInteger);
+            if( outputSHPLayer->CreateField( &processedField ) != OGRERR_NONE )
+            {
+                std::string message = std::string("Creating shapefile field \'Processed\' has failed");
+                throw rsgis::RSGISException(message);
+            }
             
             OGRFeatureDefn *featDefn = outputSHPLayer->GetLayerDefn();
             int imgClassColIdx = featDefn->GetFieldIndex(vecClassImgCol.c_str());
             int refClassColIdx = featDefn->GetFieldIndex(vecClassRefCol.c_str());
+            int processedColIdx = featDefn->GetFieldIndex("Processed");
             
             for(std::list<RSGISAccPoint*>::iterator iterPts = accPts->begin(); iterPts != accPts->end(); ++iterPts)
             {
@@ -589,6 +597,7 @@ namespace rsgis{namespace classifier{
                 
                 poFeature->SetField(imgClassColIdx, (*iterPts)->mapClassName.c_str());
                 poFeature->SetField(refClassColIdx, (*iterPts)->trueClassName.c_str());
+                poFeature->SetField(processedColIdx, 0);
                 
                 outputSHPLayer->CreateFeature(poFeature);
             }
@@ -605,7 +614,7 @@ namespace rsgis{namespace classifier{
     }
     
     
-    void RSGISGenAccuracyPoints::generateStratifiedRandomPointsVecOut(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int seed) throw(rsgis::RSGISImageException)
+    void RSGISGenAccuracyPoints::generateStratifiedRandomPointsVecOut(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int seed)
     {
         try
         {
@@ -775,10 +784,18 @@ namespace rsgis{namespace classifier{
                 std::string message = std::string("Creating shapefile field \'") + vecClassRefCol + std::string("\' has failed");
                 throw rsgis::RSGISException(message);
             }
+
+            OGRFieldDefn processedField("Processed", OFTInteger);
+            if( outputSHPLayer->CreateField( &processedField ) != OGRERR_NONE )
+            {
+                std::string message = std::string("Creating shapefile field \'Processed\' has failed");
+                throw rsgis::RSGISException(message);
+            }
             
             OGRFeatureDefn *featDefn = outputSHPLayer->GetLayerDefn();
             int imgClassColIdx = featDefn->GetFieldIndex(vecClassImgCol.c_str());
             int refClassColIdx = featDefn->GetFieldIndex(vecClassRefCol.c_str());
+            int processedColIdx = featDefn->GetFieldIndex("Processed");
             
             for(std::vector<std::vector<RSGISAccPoint*> >::iterator iterPtsVecs = accClassPts->begin(); iterPtsVecs != accClassPts->end(); ++iterPtsVecs)
             {
@@ -790,6 +807,7 @@ namespace rsgis{namespace classifier{
                     
                     poFeature->SetField(imgClassColIdx, (*iterPts)->mapClassName.c_str());
                     poFeature->SetField(refClassColIdx, (*iterPts)->trueClassName.c_str());
+                    poFeature->SetField(processedColIdx, 0);
                     
                     outputSHPLayer->CreateFeature(poFeature);
                 }
@@ -810,7 +828,7 @@ namespace rsgis{namespace classifier{
     }
     
     
-    void RSGISGenAccuracyPoints::generateStratifiedRandomPointsVecOutUsePxlLst(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int seed) throw(rsgis::RSGISImageException)
+    void RSGISGenAccuracyPoints::generateStratifiedRandomPointsVecOutUsePxlLst(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int seed)
     {
         try
         {
@@ -823,16 +841,23 @@ namespace rsgis{namespace classifier{
             }
             
             rsgis::rastergis::RSGISRasterAttUtils ratUtils;
-            std::vector<std::string> *imgClassColVals = ratUtils.readStrColumnAsVec(attTable, imgClassCol);
-            std::vector<int> *histogram = ratUtils.readIntColumnAsVec(attTable, "Histogram");
+            auto *imgClassColVals = ratUtils.readStrColumnAsVec(attTable, imgClassCol);
+            auto *histogram = ratUtils.readIntColumnAsVec(attTable, "Histogram");
             
-            std::vector<std::string> *classNames = new std::vector<std::string>();
+            auto *classNames = new std::vector<std::string>();
+            std::map<unsigned int, unsigned int> pxlValLUT;
             bool foundClassName = false;
+            unsigned int clsID = 0;
             for(size_t i = 0; i < histogram->size(); ++i)
             {
                 imgClassColVals->at(i) = boost::trim_all_copy(imgClassColVals->at(i));
                 if((histogram->at(i) > 0) & (imgClassColVals->at(i) != ""))
                 {
+                    std::cout << i << ") Class " << imgClassColVals->at(i) << " has " << histogram->at(i) << " pixels.\n";
+
+                    pxlValLUT[i] = clsID;
+                    ++clsID;
+
                     if(classNames->empty())
                     {
                         classNames->push_back(imgClassColVals->at(i));
@@ -840,7 +865,7 @@ namespace rsgis{namespace classifier{
                     else
                     {
                         foundClassName = false;
-                        for(std::vector<std::string>::iterator iterClass = classNames->begin(); iterClass != classNames->end(); ++iterClass)
+                        for(auto iterClass = classNames->begin(); iterClass != classNames->end(); ++iterClass)
                         {
                             if(*iterClass == imgClassColVals->at(i))
                             {
@@ -856,18 +881,17 @@ namespace rsgis{namespace classifier{
                     }
                 }
             }
-            
+
             unsigned long numClasses = classNames->size();
-            std::vector<std::pair<double, double> > **classPxlLst = new std::vector<std::pair<double, double> >*[numClasses];
+            auto **classPxlLst = new std::vector<std::pair<double, double> >*[numClasses];
             unsigned int idx = 0;
-            for(std::vector<std::string>::iterator iterClasses = classNames->begin(); iterClasses != classNames->end(); ++iterClasses)
+            for(auto iterClasses = classNames->begin(); iterClasses != classNames->end(); ++iterClasses)
             {
-                std::cout << "Class: \'" <<  *iterClasses << "\'" << std::endl;
                 classPxlLst[idx] = new std::vector<std::pair<double, double> >();
                 ++idx;
             }
             
-            rsgis::img::RSGISCalcImageValue *exClassPxlLocs = new RSGISExtractClassPxllocs(classPxlLst, numClasses);
+            rsgis::img::RSGISCalcImageValue *exClassPxlLocs = new RSGISExtractClassPxllocs(classPxlLst, numClasses, pxlValLUT);
             rsgis::img::RSGISCalcImage calcImg = rsgis::img::RSGISCalcImage(exClassPxlLocs);
             calcImg.calcImageExtent(&inputImage, 1, 0);
             delete exClassPxlLocs;
@@ -897,10 +921,18 @@ namespace rsgis{namespace classifier{
                 std::string message = std::string("Creating shapefile field \'") + vecClassRefCol + std::string("\' has failed");
                 throw rsgis::RSGISException(message);
             }
+
+            OGRFieldDefn processedField("Processed", OFTInteger);
+            if( outputSHPLayer->CreateField( &processedField ) != OGRERR_NONE )
+            {
+                std::string message = std::string("Creating shapefile field \'Processed\' has failed");
+                throw rsgis::RSGISException(message);
+            }
             
             OGRFeatureDefn *featDefn = outputSHPLayer->GetLayerDefn();
             int imgClassColIdx = featDefn->GetFieldIndex(vecClassImgCol.c_str());
             int refClassColIdx = featDefn->GetFieldIndex(vecClassRefCol.c_str());
+            int processedColIdx = featDefn->GetFieldIndex("Processed");
             unsigned long pxlIdx = 0;
             bool foundPxl = false;
             unsigned long findPxlIterCount = 0;
@@ -951,6 +983,7 @@ namespace rsgis{namespace classifier{
                     
                     poFeature->SetField(imgClassColIdx, classNames->at(i).c_str());
                     poFeature->SetField(refClassColIdx, classNames->at(i).c_str());
+                    poFeature->SetField(processedColIdx, 0);
                     
                     outputSHPLayer->CreateFeature(poFeature);
                 }
@@ -972,9 +1005,211 @@ namespace rsgis{namespace classifier{
             throw rsgis::RSGISImageException(e.what());
         }
     }
+
+
+
+    void RSGISGenAccuracyPoints::generateStratifiedRandomPointsVecOutUsePxlLstPropPts(GDALDataset *inputImage, OGRLayer *outputSHPLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, unsigned int numPts, unsigned int minNumPts, unsigned int seed)
+    {
+        try
+        {
+            // Get attribute table...
+            GDALRasterAttributeTable *attTable = inputImage->GetRasterBand(1)->GetDefaultRAT();
+
+            if(attTable == NULL)
+            {
+                throw RSGISImageException("The image dataset does not have an attribute table.");
+            }
+
+            rsgis::rastergis::RSGISRasterAttUtils ratUtils;
+            auto *imgClassColVals = ratUtils.readStrColumnAsVec(attTable, imgClassCol);
+            auto *histogram = ratUtils.readIntColumnAsVec(attTable, "Histogram");
+
+            auto *classNames = new std::vector<std::string>();
+            std::map<unsigned int, unsigned int> pxlValLUT;
+            bool foundClassName = false;
+            unsigned int clsID = 0;
+            for(size_t i = 0; i < histogram->size(); ++i)
+            {
+                imgClassColVals->at(i) = boost::trim_all_copy(imgClassColVals->at(i));
+                if((histogram->at(i) > 0) & (imgClassColVals->at(i) != ""))
+                {
+                    std::cout << i << ") Class " << imgClassColVals->at(i) << " has " << histogram->at(i) << " pixels.\n";
+
+                    pxlValLUT[i] = clsID;
+                    ++clsID;
+
+                    if(classNames->empty())
+                    {
+                        classNames->push_back(imgClassColVals->at(i));
+                    }
+                    else
+                    {
+                        foundClassName = false;
+                        for(auto iterClass = classNames->begin(); iterClass != classNames->end(); ++iterClass)
+                        {
+                            if(*iterClass == imgClassColVals->at(i))
+                            {
+                                foundClassName = true;
+                                break;
+                            }
+                        }
+
+                        if(!foundClassName)
+                        {
+                            classNames->push_back(imgClassColVals->at(i));
+                        }
+                    }
+                }
+            }
+
+            unsigned long numClasses = classNames->size();
+            auto **classPxlLst = new std::vector<std::pair<double, double> >*[numClasses];
+            unsigned int idx = 0;
+            for(auto iterClasses = classNames->begin(); iterClasses != classNames->end(); ++iterClasses)
+            {
+                classPxlLst[idx] = new std::vector<std::pair<double, double> >();
+                ++idx;
+            }
+
+            rsgis::img::RSGISCalcImageValue *exClassPxlLocs = new RSGISExtractClassPxllocs(classPxlLst, numClasses, pxlValLUT);
+            rsgis::img::RSGISCalcImage calcImg = rsgis::img::RSGISCalcImage(exClassPxlLocs);
+            calcImg.calcImageExtent(&inputImage, 1, 0);
+            delete exClassPxlLocs;
+
+            bool **usedPxl = new bool*[numClasses];
+            for(unsigned long i = 0; i < numClasses; ++i)
+            {
+                usedPxl[i] = new bool[classPxlLst[i]->size()];
+                for(unsigned long j = 0; j < classPxlLst[i]->size(); ++j)
+                {
+                    usedPxl[i][j] = false;
+                }
+            }
+
+            double totNumPxls = 0;
+            for(unsigned long i = 0; i < numClasses; ++i) {
+                totNumPxls += classPxlLst[i]->size();
+            }
+            std::cout << "Total number of pixels is " << totNumPxls << std::endl;
+
+            OGRFieldDefn imgClassField(vecClassImgCol.c_str(), OFTString);
+            imgClassField.SetWidth(254);
+            if( outputSHPLayer->CreateField( &imgClassField ) != OGRERR_NONE )
+            {
+                std::string message = std::string("Creating shapefile field \'") + vecClassImgCol + std::string("\' has failed");
+                throw rsgis::RSGISException(message);
+            }
+
+            OGRFieldDefn refClassField(vecClassRefCol.c_str(), OFTString);
+            refClassField.SetWidth(254);
+            if( outputSHPLayer->CreateField( &refClassField ) != OGRERR_NONE )
+            {
+                std::string message = std::string("Creating shapefile field \'") + vecClassRefCol + std::string("\' has failed");
+                throw rsgis::RSGISException(message);
+            }
+
+            OGRFieldDefn processedField("Processed", OFTInteger);
+            if( outputSHPLayer->CreateField( &processedField ) != OGRERR_NONE )
+            {
+                std::string message = std::string("Creating shapefile field \'Processed\' has failed");
+                throw rsgis::RSGISException(message);
+            }
+
+            OGRFeatureDefn *featDefn = outputSHPLayer->GetLayerDefn();
+            int imgClassColIdx = featDefn->GetFieldIndex(vecClassImgCol.c_str());
+            int refClassColIdx = featDefn->GetFieldIndex(vecClassRefCol.c_str());
+            int processedColIdx = featDefn->GetFieldIndex("Processed");
+            unsigned long pxlIdx = 0;
+            bool foundPxl = false;
+            unsigned long findPxlIterCount = 0;
+            unsigned long checkPt = 0;
+            bool usedAllPxls = false;
+            float propOfScn = 0.0;
+            unsigned long nSmplPts = 0;
+            unsigned int totNSmpls = 0;
+            for(unsigned long i = 0; i < numClasses; ++i)
+            {
+                std::cout << "Processing Class \"" << classNames->at(i) << "\"\n";
+                srand(seed);
+                checkPt = classPxlLst[i]->size();
+                propOfScn = checkPt/totNumPxls;
+                nSmplPts = floor((propOfScn * numPts)+0.5);
+                if (nSmplPts < minNumPts)
+                {
+                    nSmplPts = minNumPts;
+                }
+                if (nSmplPts > checkPt)
+                {
+                    nSmplPts = checkPt;
+                }
+                std::cout << "\t" << nSmplPts << " samples will be selected\n";
+                totNSmpls += nSmplPts;
+                for(unsigned long j = 0; j < nSmplPts; ++j)
+                {
+                    foundPxl = false;
+                    while(!foundPxl)
+                    {
+                        pxlIdx = rand() % classPxlLst[i]->size();
+                        if(!usedPxl[i][pxlIdx])
+                        {
+                            foundPxl = true;
+                            usedPxl[i][pxlIdx] = true;
+                        }
+                        else if(findPxlIterCount > checkPt)
+                        {
+                            usedAllPxls = true;
+                            for(unsigned long n = 0; n < classPxlLst[i]->size(); ++n)
+                            {
+                                if(!usedPxl[i][n])
+                                {
+                                    usedAllPxls = false;
+                                    break;
+                                }
+                            }
+
+                            if(usedAllPxls)
+                            {
+                                rsgis::utils::RSGISTextUtils txtUtils;
+                                throw rsgis::RSGISImageException("All pixels (n="+txtUtils.sizettostring(classPxlLst[i]->size())+") for class \""+classNames->at(i)+"\" have been sampled within the image");
+                            }
+                            checkPt = checkPt + classPxlLst[i]->size();
+                        }
+
+                        ++findPxlIterCount;
+                    }
+
+                    OGRFeature *poFeature = new OGRFeature(featDefn);
+                    OGRPoint *pt = new OGRPoint(classPxlLst[i]->at(pxlIdx).first, classPxlLst[i]->at(pxlIdx).second, 0.0);
+                    poFeature->SetGeometryDirectly(pt);
+
+                    poFeature->SetField(imgClassColIdx, classNames->at(i).c_str());
+                    poFeature->SetField(refClassColIdx, classNames->at(i).c_str());
+                    poFeature->SetField(processedColIdx, 0);
+
+                    outputSHPLayer->CreateFeature(poFeature);
+                }
+            }
+
+            std::cout << "Total number of samples: " << totNSmpls << std::endl;
+            delete classNames;
+            for(idx = 0; idx < numClasses; ++idx)
+            {
+                delete classPxlLst[idx];
+            }
+            delete[] classPxlLst;
+        }
+        catch(rsgis::RSGISImageException &e)
+        {
+            throw e;
+        }
+        catch(rsgis::RSGISException &e)
+        {
+            throw rsgis::RSGISImageException(e.what());
+        }
+    }
     
     
-    void RSGISGenAccuracyPoints::popClassInfo2Vec(GDALDataset *inputImage, OGRLayer *inputVecLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, bool addRefCol)throw(rsgis::RSGISImageException)
+    void RSGISGenAccuracyPoints::popClassInfo2Vec(GDALDataset *inputImage, OGRLayer *inputVecLayer, std::string imgClassCol, std::string vecClassImgCol, std::string vecClassRefCol, bool addRefCol, std::string vecProcessCol, bool addProcessCol)
     {
         try
         {
@@ -1019,7 +1254,7 @@ namespace rsgis{namespace classifier{
             imgClassField.SetWidth(254);
             if( inputVecLayer->CreateField( &imgClassField, false ) != OGRERR_NONE )
             {
-                std::string message = std::string("Creating shapefile field \'") + vecClassImgCol + std::string("\' has failed");
+                std::string message = std::string("Creating vector field \'") + vecClassImgCol + std::string("\' has failed");
                 throw rsgis::RSGISException(message);
             }
             std::string vecClassImgField = std::string(imgClassField.GetNameRef());
@@ -1031,13 +1266,21 @@ namespace rsgis{namespace classifier{
                 refClassField.SetWidth(254);
                 if( inputVecLayer->CreateField( &refClassField, false ) != OGRERR_NONE )
                 {
-                    std::string message = std::string("Creating shapefile field \'") + vecClassRefCol + std::string("\' has failed");
+                    std::string message = std::string("Creating vector field \'") + vecClassRefCol + std::string("\' has failed");
                     throw rsgis::RSGISException(message);
                 }
                 vecClassRefField = std::string(refClassField.GetNameRef());
             }
-            
-            
+
+            if(addProcessCol)
+            {
+                OGRFieldDefn processedField(vecProcessCol.c_str(), OFTInteger);
+                if (inputVecLayer->CreateField(&processedField) != OGRERR_NONE)
+                {
+                    std::string message = std::string("Creating vector field \'") + vecProcessCol + std::string("\' has failed");
+                    throw rsgis::RSGISException(message);
+                }
+            }
             
             OGRFeatureDefn *featDefn = inputVecLayer->GetLayerDefn();
             int imgClassColIdx = featDefn->GetFieldIndex(vecClassImgField.c_str());
@@ -1046,6 +1289,11 @@ namespace rsgis{namespace classifier{
             {
                 refClassColIdx = featDefn->GetFieldIndex(vecClassRefField.c_str());
             }
+            int processedColIdx = -1;
+            if(addProcessCol)
+            {
+                processedColIdx = featDefn->GetFieldIndex(vecProcessCol.c_str());
+            }
             
             int numFeatures = inputVecLayer->GetFeatureCount(TRUE);
             
@@ -1055,22 +1303,14 @@ namespace rsgis{namespace classifier{
             std::string classVal = "";
             std::string emptyStr = "";
             long pxlVal = 0.0;
-            
-            int feedback = numFeatures/10;
-            int feedbackCounter = 0;
             int i = 0;
             
             OGRFeature *featObj = NULL;
             inputVecLayer->ResetReading();
-            std::cout << "Started. " << std::flush;
+            rsgis_tqdm pbar;
             while( (featObj = inputVecLayer->GetNextFeature()) != NULL )
             {
-                if((numFeatures > 10) && ((i % feedback) == 0) && feedbackCounter <= 100)
-                {
-                    std::cout << "." << feedbackCounter << "." << std::flush;
-                    
-                    feedbackCounter = feedbackCounter + 10;
-                }
+                pbar.progress(i, numFeatures);
                 
                 // Get Geometry.
                 nullGeometry = false;
@@ -1121,6 +1361,11 @@ namespace rsgis{namespace classifier{
                             featObj->SetField(refClassColIdx, emptyStr.c_str());
                         }
                     }
+
+                    if(addProcessCol)
+                    {
+                        featObj->SetField(processedColIdx, 0);
+                    }
                     
                     if( inputVecLayer->SetFeature(featObj) != OGRERR_NONE )
                     {
@@ -1131,7 +1376,7 @@ namespace rsgis{namespace classifier{
                 OGRFeature::DestroyFeature(featObj);
                 i++;
             }
-            std::cout << ". Complete.\n";
+            pbar.finish();
             
         
         }
@@ -1146,7 +1391,7 @@ namespace rsgis{namespace classifier{
     }
     
     
-    float RSGISGenAccuracyPoints::findPixelVal(GDALDataset *image, unsigned int band, double eastings, double northings, double tlX, double tlY, double xRes, double yRes, unsigned int xSize, unsigned int ySize) throw(rsgis::RSGISImageException)
+    float RSGISGenAccuracyPoints::findPixelVal(GDALDataset *image, unsigned int band, double eastings, double northings, double tlX, double tlY, double xRes, double yRes, unsigned int xSize, unsigned int ySize)
     {
         
         double diffX = eastings - tlX;
@@ -1188,7 +1433,7 @@ namespace rsgis{namespace classifier{
         return val;
     }
     
-    std::string RSGISGenAccuracyPoints::findClassVal(GDALDataset *image, unsigned int band, GDALRasterAttributeTable *attTable, unsigned int classNameColIdx, unsigned int xPxl, unsigned int yPxl) throw(rsgis::RSGISImageException)
+    std::string RSGISGenAccuracyPoints::findClassVal(GDALDataset *image, unsigned int band, GDALRasterAttributeTable *attTable, unsigned int classNameColIdx, unsigned int xPxl, unsigned int yPxl)
     {
         if((image->GetRasterCount() < band) | (band == 0))
         {
@@ -1219,7 +1464,7 @@ namespace rsgis{namespace classifier{
         return className;
     }
     
-    std::list<std::string>* RSGISGenAccuracyPoints::findUniqueClasses(GDALRasterAttributeTable *attTable, unsigned int classNameColIdx, int histoColIdx) throw(rsgis::RSGISImageException)
+    std::list<std::string>* RSGISGenAccuracyPoints::findUniqueClasses(GDALRasterAttributeTable *attTable, unsigned int classNameColIdx, int histoColIdx)
     {
         std::list<std::string> *classes = new std::list<std::string>();
         
@@ -1272,13 +1517,14 @@ namespace rsgis{namespace classifier{
     
     
     
-    RSGISExtractClassPxllocs::RSGISExtractClassPxllocs(std::vector<std::pair<double, double> > **classPxlLst, unsigned long numClasses):rsgis::img::RSGISCalcImageValue(0)
+    RSGISExtractClassPxllocs::RSGISExtractClassPxllocs(std::vector<std::pair<double, double> > **classPxlLst, unsigned long numClasses, std::map<unsigned int, unsigned int> pxlValLUT):rsgis::img::RSGISCalcImageValue(0)
     {
         this->classPxlLst = classPxlLst;
         this->numClasses = numClasses;
+        this->pxlValLUT = pxlValLUT;
     }
     
-    void RSGISExtractClassPxllocs::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, geos::geom::Envelope extent)throw(rsgis::img::RSGISImageCalcException)
+    void RSGISExtractClassPxllocs::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals, OGREnvelope extent)
     {
         if((numIntVals != 1) & (numfloatVals != 0))
         {
@@ -1287,11 +1533,15 @@ namespace rsgis{namespace classifier{
         
         if(intBandValues[0] > 0)
         {
-            if(intBandValues[0] <= this->numClasses)
+            if(this->pxlValLUT.count(intBandValues[0]) > 0)
             {
-                double x = extent.getMinX() + (extent.getWidth()/2);
-                double y = extent.getMinY() + (extent.getHeight()/2);
-                this->classPxlLst[intBandValues[0]-1]->push_back(std::pair<double, double>(x, y));
+                unsigned int clsID = this->pxlValLUT[intBandValues[0]];
+                if (clsID <= this->numClasses)
+                {
+                    double x = extent.MinX + ((extent.MaxX - extent.MinX) / 2);
+                    double y = extent.MinY + ((extent.MaxY - extent.MinY) / 2);
+                    this->classPxlLst[clsID]->push_back(std::pair<double, double>(x, y));
+                }
             }
         }
     }
