@@ -25,10 +25,10 @@ namespace rsgis { namespace cmds {
     
 	RSGISCmdException::RSGISCmdException() : std::exception()
 	{
-		msgs = "A RSGISCmdException has been created..";
+		msgs = std::string("A RSGISCmdException has been created..");
 	}
     
-	RSGISCmdException::RSGISCmdException(const char* message) : exception()
+    RSGISCmdException::RSGISCmdException(const char* message) : std::exception()
 	{
 		msgs = std::string(message);
 	}
@@ -37,13 +37,13 @@ namespace rsgis { namespace cmds {
 	{
 		msgs = message;
 	}
-    
-	const char* RSGISCmdException::what() const throw()
+
+	const char* RSGISCmdException::what() const noexcept
 	{
 		return msgs.c_str();
 	}
     
-	RSGISCmdException::~RSGISCmdException() throw()
+	RSGISCmdException::~RSGISCmdException()
 	{
         
 	}
