@@ -38,11 +38,27 @@ namespace rsgis{namespace img{
 	{
 		numOutBands = bands;
 	}
-	
-	RSGISCalcImageValue::~RSGISCalcImageValue()
-	{
-		
-	}
 
+    
+    
+    RSGISCalcValuesFromMultiResInputs::RSGISCalcValuesFromMultiResInputs(int numberOutBands)
+    {
+        this->numOutBands = numberOutBands;
+    }
+    
+    int RSGISCalcValuesFromMultiResInputs::getNumOutBands()
+    {
+        return numOutBands;
+    }
+    
+    void RSGISCalcValuesFromMultiResInputs::setNumOutBands(int bands)
+    {
+        numOutBands = bands;
+    }
+    
+    RSGISCalcValuesFromMultiResInputs::~RSGISCalcValuesFromMultiResInputs()
+    {
+        
+    }
 	
 }} //rsgis::img
