@@ -37,7 +37,7 @@ namespace rsgis{namespace img{
 
 	}
 
-	void RSGISImageMosaic::mosaic(std::string *inputImages, int numDS, std::string outputImage, float background, bool projFromImage, std::string proj, std::string format, GDALDataType imgDataType) throw(RSGISImageException)
+	void RSGISImageMosaic::mosaic(std::string *inputImages, int numDS, std::string outputImage, float background, bool projFromImage, std::string proj, std::string format, GDALDataType imgDataType)
 	{
 		RSGISImageUtils imgUtils;
         rsgis::math::RSGISMathsUtils mathsUtils;
@@ -118,8 +118,6 @@ namespace rsgis{namespace img{
             int yBlockSize = 0;
             outputRasterBands[0]->GetBlockSize (&xBlockSize, &yBlockSize);
 
-            std::cout << "Max. block size: " << yBlockSize << std::endl;
-
 			std::cout << "Started (total " << numDS << ") ." << std::flush;
 
             for(int ds = 0; ds < numDS; ds++)
@@ -203,7 +201,7 @@ namespace rsgis{namespace img{
 			std::cout << ".complete\n";
 
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
             if(inputData != NULL)
             {
@@ -252,7 +250,7 @@ namespace rsgis{namespace img{
 		GDALClose(outputDataset);
 	}
 
-	void RSGISImageMosaic::mosaicSkipVals(std::string *inputImages, int numDS, std::string outputImage, float background, float skipVal, bool projFromImage, std::string proj, unsigned int skipBand, unsigned int overlapBehaviour, std::string format, GDALDataType imgDataType) throw(RSGISImageException)
+	void RSGISImageMosaic::mosaicSkipVals(std::string *inputImages, int numDS, std::string outputImage, float background, float skipVal, bool projFromImage, std::string proj, unsigned int skipBand, unsigned int overlapBehaviour, std::string format, GDALDataType imgDataType)
 	{
 		RSGISImageUtils imgUtils;
 		rsgis::math::RSGISMathsUtils mathsUtils;
@@ -336,8 +334,6 @@ namespace rsgis{namespace img{
             int yBlockSize = 0;
             outputRasterBands[0]->GetBlockSize (&xBlockSize, &yBlockSize);
 
-            std::cout << "Max. block size: " << yBlockSize << std::endl;
-
 			std::cout << "Started (total " << numDS << ") ." << std::flush;
 
             for(int ds = 0; ds < numDS; ds++)
@@ -568,7 +564,7 @@ namespace rsgis{namespace img{
 			std::cout << ".complete\n";
 
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
             if(inputData != NULL)
             {
@@ -628,7 +624,7 @@ namespace rsgis{namespace img{
 		GDALClose(outputDataset);
 	}
 
-	void RSGISImageMosaic::mosaicSkipThresh(std::string *inputImages, int numDS, std::string outputImage, float background, float skipLowerThresh, float skipUpperThresh, bool projFromImage, std::string proj, unsigned int threshBand, unsigned int overlapBehaviour, std::string format, GDALDataType imgDataType) throw(RSGISImageException)
+	void RSGISImageMosaic::mosaicSkipThresh(std::string *inputImages, int numDS, std::string outputImage, float background, float skipLowerThresh, float skipUpperThresh, bool projFromImage, std::string proj, unsigned int threshBand, unsigned int overlapBehaviour, std::string format, GDALDataType imgDataType)
 	{
 		RSGISImageUtils imgUtils;
         rsgis::math::RSGISMathsUtils mathsUtils;
@@ -711,8 +707,6 @@ namespace rsgis{namespace img{
             int yBlockSize = 0;
             outputRasterBands[0]->GetBlockSize (&xBlockSize, &yBlockSize);
 
-            std::cout << "Max. block size: " << yBlockSize << std::endl;
-
 			std::cout << "Started (total " << numDS << ") ." << std::flush;
 
             for(int ds = 0; ds < numDS; ds++)
@@ -943,7 +937,7 @@ namespace rsgis{namespace img{
 			std::cout << ".complete\n";
 
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
             if(inputData != NULL)
             {
@@ -1003,7 +997,7 @@ namespace rsgis{namespace img{
 		GDALClose(outputDataset);
 	}
 
-	void RSGISImageMosaic::includeDatasets(GDALDataset *baseImage, std::string *inputImages, int numDS, std::vector<int> bands, bool bandsDefined) throw(RSGISImageException)
+	void RSGISImageMosaic::includeDatasets(GDALDataset *baseImage, std::string *inputImages, int numDS, std::vector<int> bands, bool bandsDefined)
 	{
 		RSGISImageUtils imgUtils;
         GDALDataset *dataset = NULL;
@@ -1117,8 +1111,6 @@ namespace rsgis{namespace img{
             int yBlockSize = 0;
             outputBand[0]->GetBlockSize (&xBlockSize, &yBlockSize);
 
-            std::cout << "Max. block size: " << yBlockSize << std::endl;
-
 			std::cout << "Started (total " << numDS << ") ." << std::flush;
 
 			for(int i = 0; i < numDS; i++)
@@ -1224,7 +1216,7 @@ namespace rsgis{namespace img{
 			}
 			std::cout << ".complete\n";
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
 			if(imgData != NULL)
 			{
@@ -1251,7 +1243,7 @@ namespace rsgis{namespace img{
 		}
 	}
 
-    void RSGISImageMosaic::includeDatasetsSkipVals(GDALDataset *baseImage, std::string *inputImages, int numDS, std::vector<int> bands, bool bandsDefined, float skipVal) throw(RSGISImageException)
+    void RSGISImageMosaic::includeDatasetsSkipVals(GDALDataset *baseImage, std::string *inputImages, int numDS, std::vector<int> bands, bool bandsDefined, float skipVal)
     {
         RSGISImageUtils imgUtils;
         GDALDataset *dataset = NULL;
@@ -1365,9 +1357,7 @@ namespace rsgis{namespace img{
             int xBlockSize = 0;
             int yBlockSize = 0;
             outputBand[0]->GetBlockSize (&xBlockSize, &yBlockSize);
-            
-            std::cout << "Max. block size: " << yBlockSize << std::endl;
-            
+                        
             std::cout << "Started (total " << numDS << ") ." << std::flush;
             
             for(int i = 0; i < numDS; i++)
@@ -1525,7 +1515,7 @@ namespace rsgis{namespace img{
             }
             std::cout << ".complete\n";
         }
-        catch(RSGISImageBandException e)
+        catch(RSGISImageBandException &e)
         {
             if(imgInData != NULL)
             {
@@ -1556,7 +1546,7 @@ namespace rsgis{namespace img{
         }
     }
     
-    void RSGISImageMosaic::includeDatasetsIgnoreOverlap(GDALDataset *baseImage, std::string *inputImages, int numDS, int numOverlapPxls) throw(RSGISImageException)
+    void RSGISImageMosaic::includeDatasetsIgnoreOverlap(GDALDataset *baseImage, std::string *inputImages, int numDS, int numOverlapPxls)
     {
         RSGISImageUtils imgUtils;
         GDALDataset *dataset = NULL;
@@ -1648,9 +1638,7 @@ namespace rsgis{namespace img{
             int xBlockSize = 0;
             int yBlockSize = 0;
             outputBand[0]->GetBlockSize (&xBlockSize, &yBlockSize);
-            
-            std::cout << "Max. block size: " << yBlockSize << std::endl;
-            
+                        
             std::cout << "Started (total " << numDS << ") ." << std::flush;
             
             for(int i = 0; i < numDS; i++)
@@ -1715,7 +1703,7 @@ namespace rsgis{namespace img{
             }
             std::cout << ".complete\n";
         }
-        catch(RSGISImageBandException e)
+        catch(RSGISImageBandException &e)
         {
             if(imgData != NULL)
             {
@@ -1742,7 +1730,7 @@ namespace rsgis{namespace img{
         }
     }
     
-    void RSGISImageMosaic::orderInImagesValidData(std::vector<std::string> images, std::vector<std::string> *orderedImages, float noDataValue) throw(RSGISImageException)
+    void RSGISImageMosaic::orderInImagesValidData(std::vector<std::string> images, std::vector<std::string> *orderedImages, float noDataValue)
     {
         try
         {
@@ -1834,7 +1822,7 @@ namespace rsgis{namespace img{
         this->noDataVal = noDataVal;
     }
 
-    void RSGISCountValidPixels::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+    void RSGISCountValidPixels::calcImageValue(float *bandValues, int numBands) 
     {
         bool pxlIsNoData = true;
         for(int i = 0; i < numBands; ++i)
@@ -1876,7 +1864,7 @@ namespace rsgis{namespace img{
         
     }
     
-    void RSGISCombineImgTileOverview::combineKEAImgTileOverviews(GDALDataset *baseImg, std::vector<std::string> inputImages, std::vector<int> pyraScaleVals) throw(RSGISImageException)
+    void RSGISCombineImgTileOverview::combineKEAImgTileOverviews(GDALDataset *baseImg, std::vector<std::string> inputImages, std::vector<int> pyraScaleVals)
     {
         try
         {
@@ -2143,6 +2131,58 @@ namespace rsgis{namespace img{
         
     }
     
+    
+    RSGISIncludeSingleImgCalcImgVal::RSGISIncludeSingleImgCalcImgVal(int numBands, bool useNoData, float noDataVal):RSGISCalcImageValue(numBands)
+    {
+        this->useNoData = useNoData;
+        this->noDataVal = noDataVal;
+    }
+    
+    void RSGISIncludeSingleImgCalcImgVal::calcImageValue(float *bandValues, int numBands, double *output) 
+    {
+        if((this->numOutBands*2) != numBands)
+        {
+            throw RSGISImageCalcException("The number of bands does not fit the number specified.");
+        }
+        
+        bool foundNoData = false;
+        if(this->useNoData)
+        {
+            for(int i = this->numOutBands; i < numBands; ++i)
+            {
+                if(bandValues[i] == noDataVal)
+                {
+                    foundNoData = true;
+                    break;
+                }
+            }
+            
+            for(int i = 0; i < this->numOutBands; ++i)
+            {
+                 if(!foundNoData)
+                 {
+                     output[i] = bandValues[i+this->numOutBands];
+                 }
+                 else
+                 {
+                     output[i] = bandValues[i];
+                 }
+            }
+        }
+        else
+        {
+            for(int i = 0; i < this->numOutBands; ++i)
+            {
+                output[i] = bandValues[this->numOutBands+i];
+            }
+        }
+    }
+    
+    RSGISIncludeSingleImgCalcImgVal::~RSGISIncludeSingleImgCalcImgVal()
+    {
+        
+    }
+    
 
 }}
 
