@@ -29,7 +29,7 @@ namespace rsgis{namespace img{
 		
 	}
 	
-	void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats **stats, int numInputBands, bool stddev, bool useNoData, float noDataVal, bool onePassSD)throw(RSGISImageCalcException,RSGISImageBandException)
+	void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats **stats, int numInputBands, bool stddev, bool useNoData, float noDataVal, bool onePassSD)
 	{
 		RSGISCalcImageStatistics *calcImageStats = NULL;
 		RSGISCalcImage *calcImg = NULL;
@@ -50,7 +50,7 @@ namespace rsgis{namespace img{
 			
 			calcImageStats->getImageStats(stats, numInputBands);
 		}
-		catch(RSGISImageCalcException e)
+		catch(RSGISImageCalcException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -62,7 +62,7 @@ namespace rsgis{namespace img{
 			}
 			throw e;
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -85,7 +85,7 @@ namespace rsgis{namespace img{
 		}
 	}
 	
-	void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats **stats, int numInputBands, bool stddev, rsgis::math::RSGISMathFunction *func, bool useNoData, float noDataVal, bool onePassSD)throw(RSGISImageCalcException,RSGISImageBandException)
+	void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats **stats, int numInputBands, bool stddev, rsgis::math::RSGISMathFunction *func, bool useNoData, float noDataVal, bool onePassSD)
 	{
 		RSGISCalcImageStatistics *calcImageStats = NULL;
 		RSGISCalcImage *calcImg = NULL;
@@ -105,7 +105,7 @@ namespace rsgis{namespace img{
 			
 			calcImageStats->getImageStats(stats, numInputBands);
 		}
-		catch(RSGISImageCalcException e)
+		catch(RSGISImageCalcException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -117,7 +117,7 @@ namespace rsgis{namespace img{
 			}
 			throw e;
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -140,7 +140,7 @@ namespace rsgis{namespace img{
 		}
 	}
     
-    void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats *stats, bool stddev, bool useNoData, float noDataVal, bool onePassSD)throw(RSGISImageCalcException,RSGISImageBandException)
+    void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats *stats, bool stddev, bool useNoData, float noDataVal, bool onePassSD)
 	{
 		RSGISCalcImageStatisticsAllBands *calcImageStats = NULL;
 		RSGISCalcImage *calcImg = NULL;
@@ -160,7 +160,7 @@ namespace rsgis{namespace img{
 			
 			calcImageStats->getImageStats(stats);
 		}
-		catch(RSGISImageCalcException e)
+		catch(RSGISImageCalcException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -172,7 +172,7 @@ namespace rsgis{namespace img{
 			}
 			throw e;
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -195,13 +195,17 @@ namespace rsgis{namespace img{
 		}
 	}
 	
-    void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats **stats, int numInputBands, bool stddev, bool noDataSpecified, float noDataVal, bool onePassSD, double xMin, double xMax, double yMin, double yMax)throw(RSGISImageCalcException,RSGISImageBandException)
+    void RSGISImageStatistics::calcImageStatistics(GDALDataset **datasets, int numDS, ImageStats **stats, int numInputBands, bool stddev, bool noDataSpecified, float noDataVal, bool onePassSD, double xMin, double xMax, double yMin, double yMax)
     {
         RSGISCalcImageStatisticsNoData *calcImageStats = NULL;
 		RSGISCalcImage *calcImg = NULL;
 		try
 		{
-            geos::geom::Envelope *env = new geos::geom::Envelope(xMin, xMax, yMin, yMax);
+            OGREnvelope *env = new OGREnvelope();
+            env->MinX = xMin;
+            env->MaxX = xMax;
+            env->MinY = yMin;
+            env->MaxY = yMax;
             
 			calcImageStats = new RSGISCalcImageStatisticsNoData(numInputBands, false, NULL, noDataSpecified, noDataVal, onePassSD);
 			calcImg = new RSGISCalcImage(calcImageStats, "", true);
@@ -223,7 +227,7 @@ namespace rsgis{namespace img{
             
             delete env;
 		}
-		catch(RSGISImageCalcException e)
+		catch(RSGISImageCalcException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -235,7 +239,7 @@ namespace rsgis{namespace img{
 			}
 			throw e;
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -258,13 +262,17 @@ namespace rsgis{namespace img{
 		}
     }
     
-    void RSGISImageStatistics::calcImageHistogram(GDALDataset **datasets, int numDS, unsigned int imgBand, unsigned int numBins, float *binRanges, unsigned int *binCounts, bool noDataSpecified, float noDataVal, double xMin, double xMax, double yMin, double yMax)throw(RSGISImageCalcException,RSGISImageBandException)
+    void RSGISImageStatistics::calcImageHistogram(GDALDataset **datasets, int numDS, unsigned int imgBand, unsigned int numBins, float *binRanges, unsigned int *binCounts, bool noDataSpecified, float noDataVal, double xMin, double xMax, double yMin, double yMax)
     {
         RSGISCalcImageHistogramNoData *calcImageStats = NULL;
 		RSGISCalcImage *calcImg = NULL;
 		try
 		{
-            geos::geom::Envelope *env = new geos::geom::Envelope(xMin, xMax, yMin, yMax);
+            OGREnvelope *env = new OGREnvelope();
+            env->MinX = xMin;
+            env->MaxX = xMax;
+            env->MinY = yMin;
+            env->MaxY = yMax;
             
 			calcImageStats = new RSGISCalcImageHistogramNoData(imgBand, noDataSpecified, noDataVal, numBins, binRanges, binCounts);
 			calcImg = new RSGISCalcImage(calcImageStats, "", true);
@@ -273,7 +281,7 @@ namespace rsgis{namespace img{
 
             delete env;
 		}
-		catch(RSGISImageCalcException e)
+		catch(RSGISImageCalcException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -285,7 +293,7 @@ namespace rsgis{namespace img{
 			}
 			throw e;
 		}
-		catch(RSGISImageBandException e)
+		catch(RSGISImageBandException &e)
 		{
 			if(calcImageStats != NULL)
 			{
@@ -308,7 +316,7 @@ namespace rsgis{namespace img{
 		}
     }
     
-    void RSGISImageStatistics::calcImageStatisticsMask(GDALDataset *dataset, GDALDataset *imgMask, long maskVal, ImageStats **stats, double *noDataVals, bool useNoData, int numInputBands, bool stddev, bool onePassSD)throw(RSGISImageCalcException,RSGISImageBandException)
+    void RSGISImageStatistics::calcImageStatisticsMask(GDALDataset *dataset, GDALDataset *imgMask, long maskVal, ImageStats **stats, double *noDataVals, bool useNoData, int numInputBands, bool stddev, bool onePassSD)
     {
         GDALDataset **datasets = new GDALDataset*[2];
         datasets[0] = imgMask;
@@ -333,17 +341,17 @@ namespace rsgis{namespace img{
             calcImageStats.getImageStats(stats, numInputBands);
             delete[] datasets;
         }
-        catch(RSGISImageCalcException e)
+        catch(RSGISImageCalcException &e)
         {
             throw e;
         }
-        catch(RSGISImageBandException e)
+        catch(RSGISImageBandException &e)
         {
             throw e;
         }
     }
     
-    void RSGISImageStatistics::calcImageBandStatistics(GDALDataset *dataset, int imgBand, ImageStats *stats, bool stddev, bool useNoData, float noDataVal, bool onePassSD)throw(RSGISImageCalcException,RSGISImageBandException)
+    void RSGISImageStatistics::calcImageBandStatistics(GDALDataset *dataset, int imgBand, ImageStats *stats, bool stddev, bool useNoData, float noDataVal, bool onePassSD)
     {
         try
         {
@@ -394,11 +402,11 @@ namespace rsgis{namespace img{
             }
             delete[] bandStats;
         }
-        catch(RSGISImageCalcException e)
+        catch(RSGISImageCalcException &e)
         {
             throw e;
         }
-        catch(RSGISImageBandException e)
+        catch(RSGISImageBandException &e)
         {
             throw e;
         }
@@ -438,7 +446,7 @@ namespace rsgis{namespace img{
 		this->func = func;
 	}
 	
-	void RSGISCalcImageStatistics::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+	void RSGISCalcImageStatistics::calcImageValue(float *bandValues, int numBands) 
 	{
 		if(numBands != this->numInputBands)
 		{
@@ -546,7 +554,7 @@ namespace rsgis{namespace img{
         }
 	}
 	
-	void RSGISCalcImageStatistics::getImageStats(ImageStats** inStats, int numInputBands) throw(RSGISImageCalcException)
+	void RSGISCalcImageStatistics::getImageStats(ImageStats** inStats, int numInputBands) 
 	{
 		if(this->numInputBands != numInputBands)
 		{
@@ -632,7 +640,7 @@ namespace rsgis{namespace img{
 		this->func = func;
 	}
 	
-	void RSGISCalcImageStatisticsNoData::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+	void RSGISCalcImageStatisticsNoData::calcImageValue(float *bandValues, int numBands) 
 	{
 		if(numBands != this->numInputBands)
 		{
@@ -740,7 +748,7 @@ namespace rsgis{namespace img{
         }
 	}
 	
-	void RSGISCalcImageStatisticsNoData::getImageStats(ImageStats** inStats, int numInputBands) throw(RSGISImageCalcException)
+	void RSGISCalcImageStatisticsNoData::getImageStats(ImageStats** inStats, int numInputBands) 
 	{
 		if(this->numInputBands != numInputBands)
 		{
@@ -812,7 +820,7 @@ namespace rsgis{namespace img{
 		this->func = func;
 	}
 	
-	void RSGISCalcImageStatisticsAllBands::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+	void RSGISCalcImageStatisticsAllBands::calcImageValue(float *bandValues, int numBands) 
 	{
 		
 		bool foundNan = false;
@@ -912,7 +920,7 @@ namespace rsgis{namespace img{
 	}
 	
     
-	void RSGISCalcImageStatisticsAllBands::getImageStats(ImageStats *inStats) throw(RSGISImageCalcException)
+	void RSGISCalcImageStatisticsAllBands::getImageStats(ImageStats *inStats) 
 	{
 		inStats->mean = meanSum/n;
         inStats->min = min;
@@ -945,7 +953,7 @@ namespace rsgis{namespace img{
         
     }
     
-    rsgis::math::Matrix* RSGISImagePercentiles::getPercentilesForAllBands(GDALDataset* dataset, float percentile, float noDataVal, bool noDataDefined)throw(rsgis::RSGISImageException)
+    rsgis::math::Matrix* RSGISImagePercentiles::getPercentilesForAllBands(GDALDataset* dataset, float percentile, float noDataVal, bool noDataDefined)
     {
         rsgis::math::RSGISMatrices matrixUtils;
         rsgis::math::Matrix *outPercentiles = NULL;
@@ -976,7 +984,7 @@ namespace rsgis{namespace img{
         return outPercentiles;
     }
     
-    double RSGISImagePercentiles::getPercentile(GDALDataset *dataset, unsigned int band, float percentile, float noDataVal, bool noDataDefined)throw(rsgis::RSGISImageException)
+    double RSGISImagePercentiles::getPercentile(GDALDataset *dataset, unsigned int band, float percentile, float noDataVal, bool noDataDefined)
     {
         double percentileVal = 0.0;
         try
@@ -1003,7 +1011,7 @@ namespace rsgis{namespace img{
         return percentileVal;
     }
     
-    double RSGISImagePercentiles::getPercentile(GDALDataset *dataset, unsigned int band, GDALDataset *maskDS, int maskVal, float percentile, float noDataVal, bool noDataDefined)throw(rsgis::RSGISImageException)
+    double RSGISImagePercentiles::getPercentile(GDALDataset *dataset, unsigned int band, GDALDataset *maskDS, int maskVal, float percentile, float noDataVal, bool noDataDefined)
     {
         double percentileVal = 0.0;
         try
@@ -1038,7 +1046,7 @@ namespace rsgis{namespace img{
         return percentileVal;
     }
     
-    double RSGISImagePercentiles::getPercentile(GDALDataset *dataset, unsigned int band, GDALDataset *maskDS, int maskVal, float percentile, float noDataVal, bool noDataDefined, geos::geom::Envelope *env, bool quiet)throw(rsgis::RSGISImageException)
+    double RSGISImagePercentiles::getPercentile(GDALDataset *dataset, unsigned int band, GDALDataset *maskDS, int maskVal, float percentile, float noDataVal, bool noDataDefined, OGREnvelope *env, bool quiet)
     {
         double percentileVal = 0.0;
         try
@@ -1080,7 +1088,7 @@ namespace rsgis{namespace img{
 	
     
     
-    void RSGISGetPixelBandValues::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(RSGISImageCalcException)
+    void RSGISGetPixelBandValues::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(numIntVals != 1)
         {
@@ -1111,7 +1119,7 @@ namespace rsgis{namespace img{
         this->useNoDataValue = useNoDataValue;
     }
     
-    void RSGISImagePixelSummaries::calcImageValue(float *bandValues, int numBands, double *output) throw(RSGISImageCalcException)
+    void RSGISImagePixelSummaries::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         std::vector<double> *dataVals = new std::vector<double>();
         for(int i = 0; i < numBands; ++i)
@@ -1149,6 +1157,10 @@ namespace rsgis{namespace img{
         {
             output[outIdx++] = statsSummary->median;
         }
+        if(statsSummary->calcMode)
+        {
+            output[outIdx++] = statsSummary->mode;
+        }
         if(statsSummary->calcSum)
         {
             output[outIdx++] = statsSummary->sum;
@@ -1183,7 +1195,7 @@ namespace rsgis{namespace img{
         this->binCounts = binCounts;
     }
     
-    void RSGISCalcImageHistogramNoData::calcImageValue(float *bandValues, int numBands) throw(RSGISImageCalcException)
+    void RSGISCalcImageHistogramNoData::calcImageValue(float *bandValues, int numBands) 
     {
         if(this->noDataSpecified)
         {
@@ -1253,7 +1265,7 @@ namespace rsgis{namespace img{
         this->useNoData = useNoData;
     }
     
-    void RSGISCalcImageStatisticsMaskStatsNoData::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) throw(RSGISImageCalcException)
+    void RSGISCalcImageStatisticsMaskStatsNoData::calcImageValue(long *intBandValues, unsigned int numIntVals, float *floatBandValues, unsigned int numfloatVals) 
     {
         if(numfloatVals != this->numInputBands)
         {
@@ -1343,7 +1355,7 @@ namespace rsgis{namespace img{
         }
     }
     
-    void RSGISCalcImageStatisticsMaskStatsNoData::getImageStats(ImageStats** inStats, int numInputBands) throw(RSGISImageCalcException)
+    void RSGISCalcImageStatisticsMaskStatsNoData::getImageStats(ImageStats** inStats, int numInputBands) 
     {
         if(this->numInputBands != numInputBands)
         {
@@ -1454,7 +1466,7 @@ namespace rsgis{namespace img{
         this->totNumInBands = numInImgBands * numInImgs;
     }
     
-    void RSGISCalcMultiImageStatSummaries::calcImageValue(float *bandValues, int numBands, double *output) throw(RSGISImageCalcException)
+    void RSGISCalcMultiImageStatSummaries::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         if(numBands != totNumInBands)
         {
@@ -1551,7 +1563,7 @@ namespace rsgis{namespace img{
         
     }
     
-    void RSGISCalcImageDifference::calcImageValue(float *bandValues, int numBands, double *output) throw(RSGISImageCalcException)
+    void RSGISCalcImageDifference::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         if((numBands/2) != this->numOutBands)
         {
@@ -1586,7 +1598,7 @@ namespace rsgis{namespace img{
         
     }
 
-    void RSGISCalcImgStackIdxForStat::calcImageValue(float *bandValues, int numBands, double *output) throw(RSGISImageCalcException)
+    void RSGISCalcImgStackIdxForStat::calcImageValue(float *bandValues, int numBands, double *output) 
     {
         output[0] = 0.0; // Zero is output no data value.
         if(this->sumStat == rsgis::math::sumtype_min)
@@ -1689,4 +1701,78 @@ namespace rsgis{namespace img{
         }
     }
     
+    
+    
+    RSGISCalcMeanPxlValInMaskAcrossBands::RSGISCalcMeanPxlValInMaskAcrossBands(int maskVal, std::vector<unsigned int> bands, double noDataVal, bool useNoData):RSGISCalcImageValue(0)
+    {
+        this->maskVal = maskVal;
+        this->bands = bands;
+        this->noDataVal = noDataVal;
+        this->useNoData = useNoData;
+        
+        this->firstMean = true;
+        this->n = 0;
+        this->meanSum = 0.0;
+    }
+    
+    void RSGISCalcMeanPxlValInMaskAcrossBands::calcImageValue(float *bandValues, int numBands)
+    {
+        long pxlMskVal = (long) bandValues[0];
+        for(size_t i = 0; i < this->bands.size(); ++i)
+        {
+            if(pxlMskVal == this->maskVal)
+            {
+                if(this->useNoData)
+                {
+                    if(bandValues[this->bands.at(i)] != noDataVal)
+                    {
+                        if(this->firstMean)
+                        {
+                            this->meanSum = bandValues[this->bands.at(i)];
+                            this->n = 1;
+                            this->firstMean = false;
+                        }
+                        else
+                        {
+                            this->meanSum += bandValues[this->bands.at(i)];
+                            this->n += 1;
+                        }
+                    }
+                }
+                else
+                {
+                    if(this->firstMean)
+                    {
+                        this->meanSum = bandValues[this->bands.at(i)];
+                        this->n = 1;
+                        this->firstMean = false;
+                    }
+                    else
+                    {
+                        this->meanSum += bandValues[this->bands.at(i)];
+                        this->n += 1;
+                    }
+                }
+            }
+        }
+    }
+    
+    double RSGISCalcMeanPxlValInMaskAcrossBands::getMeanValue() 
+    {
+        return this->meanSum/this->n;
+    }
+    
+    void RSGISCalcMeanPxlValInMaskAcrossBands::reset()
+    {
+        this->firstMean = true;
+        this->n = 0;
+        this->meanSum = 0.0;
+    }
+    
+    RSGISCalcMeanPxlValInMaskAcrossBands::~RSGISCalcMeanPxlValInMaskAcrossBands()
+    {
+        
+    }
+    
+    
 }}
