@@ -30,30 +30,15 @@ namespace rsgis{namespace img{
 		this->n = 0;
 	}
 	
-	void RSGISPolygonPixelCount::calcImageValue(float *bandValuesImageA, float *bandValuesImageB, int numBands, int bandA, int bandB) throw(RSGISImageCalcException)
+	void RSGISPolygonPixelCount::calcImageValue(float *bandValuesImage, double interceptArea, int numBands, OGRPolygon *poly, OGRPoint *pt)
 	{
-		throw RSGISImageCalcException("Not implemented!");
-	}
-	
-	void RSGISPolygonPixelCount::calcImageValue(float *bandValuesImage, int numBands, int band) throw(RSGISImageCalcException)
-	{
-		throw RSGISImageCalcException("Not implemented!");
-	}
-	
-	void RSGISPolygonPixelCount::calcImageValue(float *bandValuesImage, int numBands, geos::geom::Envelope *extent) throw(RSGISImageCalcException)
-	{
-		throw RSGISImageCalcException("Not implemented!");
-	}
-	
-	void RSGISPolygonPixelCount::calcImageValue(float *bandValuesImage, double interceptArea, int numBands, geos::geom::Polygon *poly, geos::geom::Point *pt) throw(RSGISImageCalcException)
-	{
-		if(poly->contains(pt))
+		if(poly->Contains(pt))
 		{
 			n++;
 		}
 	}
 	
-	double* RSGISPolygonPixelCount::getOutputValues() throw(RSGISImageCalcException)
+	double* RSGISPolygonPixelCount::getOutputValues() 
 	{
 		this->outputValues[0] = n;
 		return outputValues;
